import { Injectable, ɵɵdefineInjectable, ɵɵinject, EventEmitter, Component, ChangeDetectorRef, Inject, PLATFORM_ID, ViewChild, Input, Output, NgModule } from '@angular/core';
import { isPlatformServer, CommonModule } from '@angular/common';
import { DomSanitizer } from '@angular/platform-browser';
import { fromEvent } from 'rxjs';
import { debounceTime } from 'rxjs/operators';
import { LazyLoadImageModule } from 'ng-lazyload-image';

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class CIConfig {
}
if (false) {
    /** @type {?} */
    CIConfig.prototype.token;
    /** @type {?} */
    CIConfig.prototype.container;
    /** @type {?} */
    CIConfig.prototype.ultraFast;
    /** @type {?} */
    CIConfig.prototype.lazyLoading;
    /** @type {?} */
    CIConfig.prototype.imgLoadingAnimation;
    /** @type {?} */
    CIConfig.prototype.lazyLoadOffset;
    /** @type {?} */
    CIConfig.prototype.width;
    /** @type {?} */
    CIConfig.prototype.height;
    /** @type {?} */
    CIConfig.prototype.operation;
    /** @type {?} */
    CIConfig.prototype.filters;
    /** @type {?} */
    CIConfig.prototype.placeholderBackground;
    /** @type {?} */
    CIConfig.prototype.baseUrl;
    /** @type {?} */
    CIConfig.prototype.presets;
    /** @type {?} */
    CIConfig.prototype.queryString;
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class CIService {
    /**
     * @param {?} ciConfig
     */
    constructor(ciConfig) {
        this.config = {};
        const { token = '', container = 'cloudimg.io', ultraFast = false, lazyLoading = true, imgLoadingAnimation = true, lazyLoadOffset = 100, width = '400', height = '300', operation = 'width', filters = 'foil1', placeholderBackground = '#f4f4f4', baseUrl = '/', presets, queryString = '' } = ciConfig;
        this.config = {
            token,
            container,
            ultraFast,
            lazyLoading,
            imgLoadingAnimation,
            lazyLoadOffset,
            width,
            height,
            operation,
            filters,
            placeholderBackground,
            baseUrl,
            presets: presets ? presets :
                {
                    xs: '(max-width: 575px)',
                    // to 575       PHONE
                    sm: '(min-width: 576px)',
                    // 576 - 767    PHABLET
                    md: '(min-width: 768px)',
                    // 768 - 991    TABLET
                    lg: '(min-width: 992px)',
                    // 992 - 1199   SMALL_LAPTOP_SCREEN
                    xl: '(min-width: 1200px)' // from 1200    USUALSCREEN
                },
            queryString,
            innerWidth: window.innerWidth,
            previewQualityFactor: 10
            // isChrome: /Chrome/.test(navigator.userAgent) && /Google Inc/.test(navigator.vendor)
        };
    }
    /**
     * @param {?} img
     * @param {?} config
     * @return {?}
     */
    getParentWidth(img, config) {
        if (!(img && img.parentElement && img.parentElement.getBoundingClientRect) && !(img && img.width)) {
            return config.width;
        }
        /** @type {?} */
        const parentContainer = this.getParentContainerWithWidth(img);
        /** @type {?} */
        const currentWidth = parseInt('' + parentContainer, 10);
        /** @type {?} */
        const computedWidth = Number(window.getComputedStyle(img).width);
        if ((computedWidth && (computedWidth < currentWidth && computedWidth > 15) || !currentWidth)) {
            return this.getSizeLimit(computedWidth);
        }
        else {
            if (!currentWidth) {
                return img.width || config.width;
            }
            return this.getSizeLimit(currentWidth);
        }
    }
    /**
     * @param {?} img
     * @return {?}
     */
    getParentContainerWithWidth(img) {
        /** @type {?} */
        let parentNode = null;
        /** @type {?} */
        let width = 0;
        do {
            parentNode = (parentNode && parentNode.parentNode) || img.parentNode;
            width = parentNode.getBoundingClientRect().width;
        } while (parentNode && !width);
        /** @type {?} */
        const letPadding = width && parentNode && parseInt(window.getComputedStyle(parentNode).paddingLeft, 10);
        /** @type {?} */
        const rightPadding = parseInt(window.getComputedStyle(parentNode).paddingRight, 10);
        return width + (width ? (-letPadding - rightPadding) : 0);
    }
    /**
     * @param {?} currentSize
     * @return {?}
     */
    getSizeLimit(currentSize) {
        if (currentSize <= 25) {
            return '25';
        }
        if (currentSize <= 50) {
            return '50';
        }
        return (Math.ceil(currentSize / 100) * 100).toString();
    }
    /**
     * @param {?} size
     * @return {?}
     */
    checkOnMedia(size) {
        try {
            /** @type {?} */
            const array = size.split(',');
            return array.length > 1;
        }
        catch (e) {
            return false;
        }
    }
    /**
     * @param {?} src
     * @return {?}
     */
    checkIfRelativeUrlPath(src) {
        if (src.indexOf('//') === 0) {
            src = window.location.protocol + src;
        }
        return (src.indexOf('http://') !== 0 && src.indexOf('https://') !== 0 && src.indexOf('//') !== 0);
    }
    /**
     * @param {?} src
     * @param {?=} isRelativeUrlPath
     * @param {?=} baseUrl
     * @return {?}
     */
    getImgSrc(src, isRelativeUrlPath = false, baseUrl = '') {
        if (isRelativeUrlPath) {
            return baseUrl + src;
        }
        return src;
    }
    /**
     * @param {?} size
     * @return {?}
     */
    getSizeAccordingToPixelRatio(size) {
        /** @type {?} */
        const splittedSizes = size.toString().split('x');
        /** @type {?} */
        const result = [];
        [].forEach.call(splittedSizes, (/**
         * @param {?} item
         * @return {?}
         */
        item => {
            result.push(item * Math.round(window.devicePixelRatio || 1));
        }));
        return result.join('x');
    }
    /**
     * @param {?} operation
     * @param {?} size
     * @param {?} filters
     * @param {?} imgSrc
     * @param {?} config
     * @return {?}
     */
    generateUrl(operation, size, filters, imgSrc, config) {
        const { ultraFast, token, container, queryString } = config;
        /** @type {?} */
        const isUltraFast = ultraFast ? 'https://scaleflex.ultrafast.io/' : 'https://';
        /** @type {?} */
        const cloudUrl = isUltraFast + token + '.' + container + '/';
        return cloudUrl + operation + '/' + size + '/' + filters + '/' + imgSrc + queryString;
    }
    /**
     * @param {?} operation
     * @param {?} size
     * @param {?} filters
     * @param {?} imgSrc
     * @param {?} isAdaptive
     * @param {?} config
     * @param {?} isPreview
     * @return {?}
     */
    generateSources(operation, size, filters, imgSrc, isAdaptive, config, isPreview) {
        const { previewQualityFactor } = config;
        /** @type {?} */
        const sources = [];
        if (isAdaptive) {
            size.forEach((/**
             * @param {?} __0
             * @return {?}
             */
            ({ size: nextSize, media: mediaQuery }) => {
                if (isPreview) {
                    nextSize = nextSize.split('x').map((/**
                     * @param {?} sizeNext
                     * @return {?}
                     */
                    sizeNext => Math.floor(sizeNext / previewQualityFactor))).join('x');
                }
                sources.push({ mediaQuery, srcSet: this.generateSrcset(operation, nextSize, filters, imgSrc, config) });
            }));
        }
        else {
            if (isPreview) {
                size = size.split('x').map((/**
                 * @param {?} sizeNext
                 * @return {?}
                 */
                sizeNext => Math.floor(sizeNext / previewQualityFactor))).join('x');
            }
            sources.push({
                srcSet: this.generateSrcset(operation, size, filters, imgSrc, config)
            });
        }
        return sources;
    }
    /**
     * @param {?} size
     * @param {?} config
     * @return {?}
     */
    getAdaptiveSize(size, config) {
        /** @type {?} */
        const arrayOfSizes = size.split(',');
        /** @type {?} */
        const sizes = [];
        arrayOfSizes.forEach((/**
         * @param {?} string
         * @return {?}
         */
        string => {
            /** @type {?} */
            const groups = string.match(/(([a-z_][a-z_]*)|(\([\S\s]*\)))\s*([0-9xp]*)/);
            /** @type {?} */
            const media = groups[3] ? groups[3] : config.presets[groups[2]];
            sizes.push({ media, size: groups[4] });
        }));
        return sizes;
    }
    /**
     * @param {?} operation
     * @param {?} size
     * @param {?} filters
     * @param {?} imgSrc
     * @param {?} config
     * @return {?}
     */
    generateSrcset(operation, size, filters, imgSrc, config) {
        const [imgWidth, imgHeight] = size.toString().split('x');
        return this.generateImgSrc(operation, filters, imgSrc, imgWidth, imgHeight, 1, config);
    }
    /**
     * @param {?} operation
     * @param {?} filters
     * @param {?} imgSrc
     * @param {?} imgWidth
     * @param {?} imgHeight
     * @param {?} factor
     * @param {?} config
     * @return {?}
     */
    generateImgSrc(operation, filters, imgSrc, imgWidth, imgHeight, factor, config) {
        /** @type {?} */
        let imgSize = '' + Math.trunc(imgWidth * factor);
        if (imgHeight) {
            imgSize += 'x' + Math.trunc(imgHeight * factor);
        }
        return this.generateUrl(operation, this.getSizeAccordingToPixelRatio(imgSize), filters, imgSrc, config)
            .replace('http://scaleflex.ultrafast.io/', '')
            .replace('https://scaleflex.ultrafast.io/', '')
            .replace('//scaleflex.ultrafast.io/', '')
            .replace('///', '/');
    }
    /**
     * @param {?} size
     * @param {?} config
     * @return {?}
     */
    getRatioBySize(size, config) {
        /** @type {?} */
        let width;
        /** @type {?} */
        let height;
        if (typeof size === 'object') {
            /** @type {?} */
            const breakPointSource = this.getBreakPoint(size);
            /** @type {?} */
            const breakPointSize = breakPointSource ? breakPointSource.size : size[0].size;
            [width, height] = breakPointSize.toString().split('x');
        }
        else {
            [width, height] = size.toString().split('x');
        }
        if (width && height) {
            return width / height;
        }
        return null;
    }
    /**
     * @param {?} size
     * @return {?}
     */
    getBreakPoint(size) {
        return [...size].reverse().find((/**
         * @param {?} item
         * @return {?}
         */
        item => matchMedia(item.media).matches));
    }
}
CIService.decorators = [
    { type: Injectable, args: [{
                providedIn: 'root'
            },] }
];
/** @nocollapse */
CIService.ctorParameters = () => [
    { type: CIConfig }
];
/** @nocollapse */ CIService.ngInjectableDef = ɵɵdefineInjectable({ factory: function CIService_Factory() { return new CIService(ɵɵinject(CIConfig)); }, token: CIService, providedIn: "root" });
if (false) {
    /** @type {?} */
    CIService.prototype.config;
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class ImgComponent {
    /**
     * @param {?} ciService
     * @param {?} _sanitizer
     * @param {?} cd
     * @param {?} platformId
     */
    constructor(ciService, _sanitizer, cd, platformId) {
        this.ciService = ciService;
        this._sanitizer = _sanitizer;
        this.cd = cd;
        this.platformId = platformId;
        this.class = '';
        this.offset = 100;
        this.lazyLoading = null;
        this.emptyOnSsr = false;
        this.imageLoaded = new EventEmitter();
        this.cloudimageUrl = '';
        this.sources = [];
        this.firstSource = null;
        this.restSources = [];
        this.isLoaded = false;
        this.isProcessed = false;
        this.windowInnerWidth = window.innerWidth;
        this.isSsr = isPlatformServer(platformId);
    }
    /**
     * @return {?}
     */
    get isLazyLoadingMode() {
        if (this.isSsr) {
            return false;
        }
        if (typeof this.lazyLoading === 'boolean') {
            return this.lazyLoading;
        }
        return this.ciService.config.lazyLoading || false;
    }
    /**
     * @return {?}
     */
    ngOnDestroy() {
        this.resizeSubscription$.unsubscribe();
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        this.resizeObservable$ = fromEvent(window, 'resize').pipe(debounceTime(500));
        this.resizeSubscription$ = this.resizeObservable$.subscribe((/**
         * @return {?}
         */
        () => {
            if (this.isAdaptive || this.windowInnerWidth < window.innerWidth) {
                this.processImage();
            }
            this.windowInnerWidth = window.innerWidth;
        }));
    }
    /**
     * @param {?} changes
     * @return {?}
     */
    ngOnChanges(changes) {
        /** @type {?} */
        const srcChanged = changes.src && changes.src.previousValue !== changes.src.currentValue && !changes.src.firstChange;
        /** @type {?} */
        const ratioChanged = changes.ratio && changes.ratio.previousValue !== changes.ratio.currentValue && !changes.ratio.firstChange;
        if (srcChanged || ratioChanged) {
            this.processImage();
        }
    }
    /**
     * @return {?}
     */
    ngAfterViewInit() {
        this.processImage();
    }
    /**
     * @return {?}
     */
    processImage() {
        /** @type {?} */
        const imgNode = (this.imgElem || this.pictureElem).nativeElement;
        const { config = {} } = this.ciService;
        const { previewQualityFactor } = config;
        /** @type {?} */
        const operation = this.operation || this.o || config.operation;
        /** @type {?} */
        const parentContainerWidth = this.ciService.getParentWidth(imgNode, config);
        /** @type {?} */
        let size = this.size || this.s || config.size || parentContainerWidth;
        /** @type {?} */
        const filters = this.filters || this.f || config.filters;
        /** @type {?} */
        const isAdaptive = this.ciService.checkOnMedia(size);
        size = isAdaptive ? this.ciService.getAdaptiveSize(size, config) : size;
        /** @type {?} */
        const isRelativeUrlPath = this.ciService.checkIfRelativeUrlPath(this.src);
        /** @type {?} */
        const imgSrc = this.ciService.getImgSrc(this.src, isRelativeUrlPath, config.baseUrl);
        /** @type {?} */
        const resultSize = isAdaptive ? size : this.ciService.getSizeAccordingToPixelRatio(size);
        this.isPreview = !config.isChrome && (parentContainerWidth > 400) && this.isLazyLoadingMode;
        this.cloudimageUrl = isAdaptive ?
            this.ciService.generateUrl('width', this.ciService.getSizeAccordingToPixelRatio(parentContainerWidth), filters, imgSrc, config) :
            this.ciService.generateUrl(operation, resultSize, filters, imgSrc, config);
        this.sources = isAdaptive ?
            this.ciService.generateSources(operation, resultSize, filters, imgSrc, isAdaptive, config, false) : [];
        /** @type {?} */
        let previewCloudimageUrl;
        /** @type {?} */
        let previewSources;
        if (this.isPreview) {
            /** @type {?} */
            const previewConfig = Object.assign({}, config, { queryString: '' });
            previewCloudimageUrl = isAdaptive ?
                this.ciService.generateUrl('width', (Math.floor(parentContainerWidth / previewQualityFactor)), filters, imgSrc, previewConfig) :
                this.ciService.generateUrl(operation, resultSize.split('x').map((/**
                 * @param {?} item
                 * @return {?}
                 */
                item => Math.floor(item / previewQualityFactor))).join('x'), filters, imgSrc, previewConfig);
            previewSources = isAdaptive ?
                this.ciService.generateSources(operation, resultSize, filters, imgSrc, isAdaptive, previewConfig, true) : [];
        }
        this.previewCloudimageUrl = previewCloudimageUrl;
        this.previewSources = previewSources;
        this.isAdaptive = isAdaptive;
        this.actualSize = size;
        this.parentContainerWidth = parentContainerWidth;
        /** @type {?} */
        const ratioBySize = this.ciService.getRatioBySize(size, config);
        this.imageHeight = Math.floor(parentContainerWidth / (ratioBySize || this.ratio || 1.5));
        this.isRatio = !!(ratioBySize || this.ratio);
        this.ratioBySize = ratioBySize;
        this.isProcessed = true;
        this.cd.detectChanges();
    }
    /**
     * @param {?} $event
     * @return {?}
     */
    onImageLoad($event) {
        if (!this.isPreview) {
            this.isPreviewLoaded = true;
            this.isLoaded = true;
        }
        else if (this.isPreviewLoaded) {
            this.isLoaded = true;
        }
        else {
            this.isPreviewLoaded = true;
        }
        this.imageLoaded.emit($event);
    }
    /**
     * @return {?}
     */
    getRestSources() {
        /** @type {?} */
        const resultSources = [...(!this.isPreview ? this.sources : (this.isPreviewLoaded ? this.sources : this.previewSources))];
        return resultSources.slice(1).reverse();
    }
    /**
     * @return {?}
     */
    getFirstSource() {
        /** @type {?} */
        const resultSources = [...(!this.isPreview ? this.sources : (this.isPreviewLoaded ? this.sources : this.previewSources))];
        this.firstSource = resultSources[0];
        return resultSources[0];
    }
    /**
     * @return {?}
     */
    getPositionStyle() {
        return this._sanitizer.bypassSecurityTrustStyle(this.isRatio ? 'absolute' : 'relative');
    }
    /**
     * @return {?}
     */
    getImgHeight() {
        // todo check if we need 100% height
        // return this._sanitizer.bypassSecurityTrustStyle(this.isRatio ? '100%' : 'auto');
        return this._sanitizer.bypassSecurityTrustStyle(this.isRatio ? 'auto' : 'auto');
    }
    /**
     * @return {?}
     */
    getTransformStyle() {
        const { config } = this.ciService;
        /** @type {?} */
        let result = 'none';
        if (config.imgLoadingAnimation) {
            result = 'scale3d(1.1, 1.1, 1)';
        }
        if (this.isLoaded && config.imgLoadingAnimation) {
            result = 'translateZ(0) scale3d(1, 1, 1)';
        }
        return this._sanitizer.bypassSecurityTrustStyle(result);
    }
    /**
     * @return {?}
     */
    getTransitionStyle() {
        const { config } = this.ciService;
        /** @type {?} */
        let result = 'none';
        if (this.isLoaded && config.imgLoadingAnimation) {
            result = 'all 0.3s ease-in-out';
        }
        return this._sanitizer.bypassSecurityTrustStyle(result);
    }
    /**
     * @return {?}
     */
    getFilterStyle() {
        const { config } = this.ciService;
        /** @type {?} */
        let result = 'none';
        if (config.imgLoadingAnimation) {
            result = `blur(${Math.floor(parseInt(this.parentContainerWidth, 10) / 100)}px)`;
        }
        if (this.isLoaded && config.imgLoadingAnimation) {
            result = 'blur(0px)';
        }
        return this._sanitizer.bypassSecurityTrustStyle(result);
    }
    /**
     * @return {?}
     */
    getPicturePaddingBottom() {
        /** @type {?} */
        let result = '';
        if (this.isRatio) {
            result = (100 / (this.ratioBySize || this.ratio)) + '%';
        }
        return this._sanitizer.bypassSecurityTrustStyle(result);
    }
    /**
     * @return {?}
     */
    getPictureBackground() {
        const { config } = this.ciService;
        /** @type {?} */
        let result = 'transparent';
        if (this.isRatio && !this.isPreviewLoaded && !this.isLoaded) {
            result = config.placeholderBackground;
        }
        return this._sanitizer.bypassSecurityTrustStyle(result);
    }
}
ImgComponent.decorators = [
    { type: Component, args: [{
                selector: 'ci-img',
                template: "<picture *ngIf=\"!isProcessed\" #pictureElem></picture>\n\n<ng-container *ngIf=\"isProcessed\">\n  <picture\n    [class]=\"class + ' cloudimage-image-picture cloudimage-image-' + (isLoaded ? 'loaded' : 'loading')\"\n    style=\"display:block;width:100%;overflow:hidden;position:relative;\"\n    [style.paddingBottom]=\"getPicturePaddingBottom()\"\n    [style.background]=\"getPictureBackground()\"\n    #imgElem\n    *ngIf=\"isProcessed\"\n  >\n    <ng-container *ngIf=\"isLazyLoadingMode; then lazyLoadingTpl else notLazyLoadingTpl\"></ng-container>\n  </picture>\n</ng-container>\n\n<ng-template #lazyLoadingTpl>\n  <source\n    *ngFor=\"let source of getRestSources()\"\n    [media]=\"source.mediaQuery || ''\"\n    [attr.lazyLoad]=\"source.srcSet || ''\"\n    (load)=\"onImageLoad($event)\"\n  />\n  <source\n    *ngIf=\"getFirstSource()\"\n    [attr.lazyLoad]=\"firstSource.srcSet || ''\"\n    (load)=\"onImageLoad($event)\"\n  />\n  <img\n    style=\"display:block;width:100%;opacity:1;top:0;left:0;\"\n    [style.position]=\"getPositionStyle()\"\n    [style.height]=\"getImgHeight()\"\n    [style.paddingBottom]=\"getPicturePaddingBottom()\"\n    [style.transform]=\"getTransformStyle()\"\n    [style.transition]=\"getTransitionStyle()\"\n    [style.filter]=\"getFilterStyle()\"\n    (load)=\"onImageLoad($event)\"\n    [lazyLoad]=\"!isPreview || isPreviewLoaded ? cloudimageUrl : previewCloudimageUrl\"\n    [offset]=\"offset\"\n    [attr.alt]=\"alt\"\n  />\n</ng-template>\n\n<ng-template #notLazyLoadingTpl>\n  <source\n    *ngFor=\"let source of restSources\"\n    [media]=\"source.mediaQuery || ''\"\n    [srcset]=\"source.srcSet || ''\"\n    (load)=\"onImageLoad($event)\"\n  />\n  <source\n    *ngIf=\"firstSource\"\n    [srcset]=\"firstSource.srcSet || ''\"\n    (load)=\"onImageLoad($event)\"\n  />\n  <img\n    *ngIf=\"!(isSsr && emptyOnSsr)\"\n    style=\"display:block;width:100%;opacity:1;top:0;left:0;\"\n    [style.position]=\"getPositionStyle()\"\n    [style.height]=\"getImgHeight()\"\n    [style.transform]=\"getTransformStyle()\"\n    [style.transition]=\"getTransitionStyle()\"\n    [style.filter]=\"getFilterStyle()\"\n    (load)=\"onImageLoad($event)\"\n    [src]=\"!isPreview || isPreviewLoaded ? cloudimageUrl : previewCloudimageUrl\"\n    [attr.alt]=\"alt\"\n  />\n</ng-template>\n"
            }] }
];
/** @nocollapse */
ImgComponent.ctorParameters = () => [
    { type: CIService },
    { type: DomSanitizer },
    { type: ChangeDetectorRef },
    { type: Object, decorators: [{ type: Inject, args: [PLATFORM_ID,] }] }
];
ImgComponent.propDecorators = {
    imgElem: [{ type: ViewChild, args: ['imgElem', { static: false },] }],
    pictureElem: [{ type: ViewChild, args: ['pictureElem', { static: false },] }],
    src: [{ type: Input }],
    class: [{ type: Input }],
    alt: [{ type: Input }],
    operation: [{ type: Input }],
    o: [{ type: Input }],
    size: [{ type: Input }],
    s: [{ type: Input }],
    filters: [{ type: Input }],
    f: [{ type: Input }],
    ratio: [{ type: Input }],
    offset: [{ type: Input }],
    ngSwitch: [{ type: Input }],
    lazyLoading: [{ type: Input }],
    emptyOnSsr: [{ type: Input }],
    imageLoaded: [{ type: Output }]
};
if (false) {
    /** @type {?} */
    ImgComponent.prototype.imgElem;
    /** @type {?} */
    ImgComponent.prototype.pictureElem;
    /** @type {?} */
    ImgComponent.prototype.src;
    /** @type {?} */
    ImgComponent.prototype.class;
    /** @type {?} */
    ImgComponent.prototype.alt;
    /** @type {?} */
    ImgComponent.prototype.operation;
    /** @type {?} */
    ImgComponent.prototype.o;
    /** @type {?} */
    ImgComponent.prototype.size;
    /** @type {?} */
    ImgComponent.prototype.s;
    /** @type {?} */
    ImgComponent.prototype.filters;
    /** @type {?} */
    ImgComponent.prototype.f;
    /** @type {?} */
    ImgComponent.prototype.ratio;
    /** @type {?} */
    ImgComponent.prototype.offset;
    /** @type {?} */
    ImgComponent.prototype.ngSwitch;
    /** @type {?} */
    ImgComponent.prototype.lazyLoading;
    /** @type {?} */
    ImgComponent.prototype.emptyOnSsr;
    /** @type {?} */
    ImgComponent.prototype.imageLoaded;
    /** @type {?} */
    ImgComponent.prototype.resizeObservable$;
    /** @type {?} */
    ImgComponent.prototype.resizeSubscription$;
    /** @type {?} */
    ImgComponent.prototype.cloudimageUrl;
    /** @type {?} */
    ImgComponent.prototype.sources;
    /** @type {?} */
    ImgComponent.prototype.firstSource;
    /** @type {?} */
    ImgComponent.prototype.restSources;
    /** @type {?} */
    ImgComponent.prototype.isLoaded;
    /** @type {?} */
    ImgComponent.prototype.isProcessed;
    /** @type {?} */
    ImgComponent.prototype.isPreview;
    /** @type {?} */
    ImgComponent.prototype.previewCloudimageUrl;
    /** @type {?} */
    ImgComponent.prototype.previewSources;
    /** @type {?} */
    ImgComponent.prototype.isAdaptive;
    /** @type {?} */
    ImgComponent.prototype.actualSize;
    /** @type {?} */
    ImgComponent.prototype.parentContainerWidth;
    /** @type {?} */
    ImgComponent.prototype.isPreviewLoaded;
    /** @type {?} */
    ImgComponent.prototype.isRatio;
    /** @type {?} */
    ImgComponent.prototype.ratioBySize;
    /** @type {?} */
    ImgComponent.prototype.imageHeight;
    /** @type {?} */
    ImgComponent.prototype.windowInnerWidth;
    /** @type {?} */
    ImgComponent.prototype.isSsr;
    /**
     * @type {?}
     * @private
     */
    ImgComponent.prototype.ciService;
    /**
     * @type {?}
     * @private
     */
    ImgComponent.prototype._sanitizer;
    /**
     * @type {?}
     * @private
     */
    ImgComponent.prototype.cd;
    /**
     * @type {?}
     * @private
     */
    ImgComponent.prototype.platformId;
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class CIModule {
}
CIModule.decorators = [
    { type: NgModule, args: [{
                declarations: [ImgComponent],
                imports: [CommonModule, LazyLoadImageModule],
                exports: [ImgComponent],
                providers: []
            },] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

export { CIConfig, CIModule, CIService, ImgComponent };
//# sourceMappingURL=ng-cloudimage-responsive.js.map
